indexing

	description: "Tests for element content."


deferred class

   TEST_CONTENT


inherit

	TS_TEST_CASE

	GF_FORMAT


feature {NONE} -- State

   validator: XM_VALIDATING_PARSER is
			-- Our validating parser, based upon Expat.
		local
			xp: XM_EXPAT_PARSER
			v: XM_VALIDATING_PARSER
      once
			create xp.make
			create v.make (xp)
			Result := v
      end


feature -- The big test

   test_all is
      do
         test1
         test1_bad1

			test2

			test3
         test3_bad1
      end

   do_parse (filename: STRING; expected_result: BOOLEAN; assert_msg: STRING) is
		require
			filename_not_empty: filename /= Void and then not filename.is_empty
			assert_msg_not_empty: not expected_result implies (assert_msg /= Void and then not assert_msg.is_empty)
		local
			file: KL_TEXT_INPUT_FILE
      do
			debug ("XML")
				print ("Parsing: ")
				print (filename)
				print ("%N")
			end
			create file.make (filename)
			file.open_read
				check
					file_open: file.is_open_read
				end
         validator.parse_from_stream (file)

			debug ("XML")
				if not validator.is_correct then
					print ("Some error: ")
					print (validator.last_error_extended_description)
					print ("%N")
				end
			end

			if expected_result then
				assert (format("Expected parsing of ?s ok:", <<filename>>), validator.is_correct)
			else
				assert (assert_msg, not validator.is_correct)
			end
      end


feature -- test1, no content allowed

   test1 is
         -- Most basic test, just check if things are working.
      local
         root: DEFINED_ELEMENT_EMPTY
      do
         validator.wipe_out_schema

         -- build this DTD:
         -- <!ELEMENT root EMPTY>
         create root.make ("root")
         validator.add_element (root)

         do_parse ("test1_ok1.xml", True, Void)
         do_parse ("test1_ok2.xml", True, Void)
      end

   test1_bad1 is
         -- As `test1', but pass not allowed char data.
      do
			do_parse ("test1_bad1.xml", False, "Should complain about character data.")
      end


feature -- test2, any content allowed

   test2 is
         -- Test #PCDATA.
      local
         root: DEFINED_ELEMENT_TEXT
      do
         validator.wipe_out_schema

         -- build this DTD:
         -- <!ELEMENT root EMPTY>
         create root.make ("root", Void)
         validator.add_element (root)

         do_parse ("test2_ok1.xml", True, Void)
         do_parse ("test2_ok2.xml", True, Void)
      end


feature -- test3, integer content allowed

   test3 is
         -- Test for integers.
      local
         root: DEFINED_ELEMENT_TEXT
      do
         validator.wipe_out_schema

         -- build this DTD:
         -- <!ELEMENT root EMPTY>
         create root.make ("root", "[0-9]+")
         validator.add_element (root)

         do_parse ("test3_ok1.xml", True, Void)
      end

   test3_bad1 is
         -- As `test3', but pass alpha instead of integer.
      do
			do_parse ("test3_bad1.xml", False, "Should complain about contents.")
      end


end
